parse_html_bookmarks

Function parse_html_bookmarks 

pub fn parse_html_bookmarks(html_path: &Path) -> Result<Value>
Parses HTML bookmarks file and converts it to a JSON value.

Arguments

  • html_path - A reference to a Path representing the file path of the HTML bookmarks.

Returns

  • Returns an io::Result containing a serde_json::Value representing the parsed bookmarks.